@@ -4,6 +4,6 @@ APP_NAME=ubufox
 CHROME_PROVIDERS="content locale skin"
 CLEAN_UP=1
 ROOT_FILES=
-ROOT_DIRS="defaults searchplugins"
+ROOT_DIRS="defaults searchplugins components"
 BEFORE_BUILD=
 AFTER_BUILD=
