@@ -262,7 +262,7 @@ nsPluginInstallerWizard.prototype.showPluginList = function () {
 
       var descDesc = document.createElement("description");
       if (!pluginInfo.desc) {
-        pluginInfo.desc = "No description found in plugin database. \nReport a bug to ubuntu-mozillateam@lists.ubuntu.com";
+        pluginInfo.desc = this.getString("ubufox.pluginWizard.description.notfound");
       }
       descDesc.appendChild(document.createTextNode(pluginInfo.desc));
       descDesc.setAttribute("style", "white-space: pre;");
