@@ -39,11 +39,12 @@ echo -- Inserting Data ...
 echo
 echo
 
-distributionIDs="7.10 8.04 8.10"
+distributionIDs="7.10 8.04 8.10 9.04"
 
 archs_7_10="amd64 i386 powerpc sparc"
 archs_8_04="amd64 i386"
 archs_8_10="amd64 i386"
+archs_9_04="amd64 i386"
 
 for distro in $distributionIDs; do
 
